.. :changelog:

History
-------

0.0.1 (08-10-2020)
---------------------

* First code creation


0.1.0 (26-03-2021)
------------------

* Add several modules, add feature to create effects for canvas items, reword documentation, refactor two main window canvas attributes


0.2.0 (30-03-2021)
------------------

* Add feature for a user to send commands, add code for changing the state of menu bar entries, document more comments and docstrings


0.2.1 (11-04-2021)
------------------

* Add docstrings for adapter classes, bump dependency to latest powermole library package


0.2.2 (18-05-2021)
------------------

* Refactor main window code for simplicity and readability


0.2.3 (25-05-2021)
------------------

* Redraw Agent's movement to be more accurate, refactor a bunch of public methods into protected ones, add docstrings for all canvas items, remove the creation of the canvas item objects during initialization, remove the scaling feature


0.2.4 (01-06-2021)
------------------

* Reword status messages in status banner, reword documentation, bump dependency to latest powermole library package, add feature to set heartbeat interval value


0.2.5 (06-06-2021)
------------------

* Bump dependency to latest powermole library package, fix bug to terminate the right thread, redraw animation for demo purposes, reword commit messages associated with releases, add instructions how to execute powermolegui, reword list of keywords for PyPi


0.2.6 (02-12-2021)
------------------

* Bump dependency to latest powermole library package


0.2.7 (28-12-2021)
------------------

* Bump dependency to latest powermole library package, reword email address, and fix bug responsible for crashing when user hits Ctrl+C in shell


0.2.8 (20-08-2022)
------------------

* Document paragraph Requirements for macOS Monterey


0.2.9 (21-08-2022)
------------------

* Fix unexpected indentation in README
